
# Slot: edge_list_is_complete


Whether to consider the edge list as complete, i.e. the edges are presented in both directions when loading an undirected graph.

URI: [https://w3id.org/neat/ensmallenRunConfig__edge_list_is_complete](https://w3id.org/neat/ensmallenRunConfig__edge_list_is_complete)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
